# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1SamlOrganizationStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {'created_at': 'datetime', 'updated_at': 'datetime', 'user_ids': 'list[str]'}

    attribute_map = {'created_at': 'createdAt', 'updated_at': 'updatedAt', 'user_ids': 'userIds'}

    def __init__(self, created_at=None, updated_at=None, user_ids=None, _configuration=None):  # noqa: E501
        """V1SamlOrganizationStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_at = None
        self._updated_at = None
        self._user_ids = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if user_ids is not None:
            self.user_ids = user_ids

    @property
    def created_at(self):
        """Gets the created_at of this V1SamlOrganizationStatus.  # noqa: E501


        :return: The created_at of this V1SamlOrganizationStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this V1SamlOrganizationStatus.


        :param created_at: The created_at of this V1SamlOrganizationStatus.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this V1SamlOrganizationStatus.  # noqa: E501


        :return: The updated_at of this V1SamlOrganizationStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this V1SamlOrganizationStatus.


        :param updated_at: The updated_at of this V1SamlOrganizationStatus.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def user_ids(self):
        """Gets the user_ids of this V1SamlOrganizationStatus.  # noqa: E501


        :return: The user_ids of this V1SamlOrganizationStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this V1SamlOrganizationStatus.


        :param user_ids: The user_ids of this V1SamlOrganizationStatus.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1SamlOrganizationStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SamlOrganizationStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1SamlOrganizationStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1EKSCusterDriverStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ecr_registry_id': 'str',
        'ecr_repository_uri': 'str',
        'gridlet_role_arn': 'str',
        'user_workload_role_arn': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'ecr_registry_id': 'ecrRegistryId',
        'ecr_repository_uri': 'ecrRepositoryUri',
        'gridlet_role_arn': 'gridletRoleArn',
        'user_workload_role_arn': 'userWorkloadRoleArn',
        'vpc_id': 'vpcId'
    }

    def __init__(
        self,
        ecr_registry_id=None,
        ecr_repository_uri=None,
        gridlet_role_arn=None,
        user_workload_role_arn=None,
        vpc_id=None,
        _configuration=None
    ):  # noqa: E501
        """V1EKSCusterDriverStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ecr_registry_id = None
        self._ecr_repository_uri = None
        self._gridlet_role_arn = None
        self._user_workload_role_arn = None
        self._vpc_id = None
        self.discriminator = None

        if ecr_registry_id is not None:
            self.ecr_registry_id = ecr_registry_id
        if ecr_repository_uri is not None:
            self.ecr_repository_uri = ecr_repository_uri
        if gridlet_role_arn is not None:
            self.gridlet_role_arn = gridlet_role_arn
        if user_workload_role_arn is not None:
            self.user_workload_role_arn = user_workload_role_arn
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def ecr_registry_id(self):
        """Gets the ecr_registry_id of this V1EKSCusterDriverStatus.  # noqa: E501


        :return: The ecr_registry_id of this V1EKSCusterDriverStatus.  # noqa: E501
        :rtype: str
        """
        return self._ecr_registry_id

    @ecr_registry_id.setter
    def ecr_registry_id(self, ecr_registry_id):
        """Sets the ecr_registry_id of this V1EKSCusterDriverStatus.


        :param ecr_registry_id: The ecr_registry_id of this V1EKSCusterDriverStatus.  # noqa: E501
        :type: str
        """

        self._ecr_registry_id = ecr_registry_id

    @property
    def ecr_repository_uri(self):
        """Gets the ecr_repository_uri of this V1EKSCusterDriverStatus.  # noqa: E501


        :return: The ecr_repository_uri of this V1EKSCusterDriverStatus.  # noqa: E501
        :rtype: str
        """
        return self._ecr_repository_uri

    @ecr_repository_uri.setter
    def ecr_repository_uri(self, ecr_repository_uri):
        """Sets the ecr_repository_uri of this V1EKSCusterDriverStatus.


        :param ecr_repository_uri: The ecr_repository_uri of this V1EKSCusterDriverStatus.  # noqa: E501
        :type: str
        """

        self._ecr_repository_uri = ecr_repository_uri

    @property
    def gridlet_role_arn(self):
        """Gets the gridlet_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501


        :return: The gridlet_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501
        :rtype: str
        """
        return self._gridlet_role_arn

    @gridlet_role_arn.setter
    def gridlet_role_arn(self, gridlet_role_arn):
        """Sets the gridlet_role_arn of this V1EKSCusterDriverStatus.


        :param gridlet_role_arn: The gridlet_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501
        :type: str
        """

        self._gridlet_role_arn = gridlet_role_arn

    @property
    def user_workload_role_arn(self):
        """Gets the user_workload_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501


        :return: The user_workload_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501
        :rtype: str
        """
        return self._user_workload_role_arn

    @user_workload_role_arn.setter
    def user_workload_role_arn(self, user_workload_role_arn):
        """Sets the user_workload_role_arn of this V1EKSCusterDriverStatus.


        :param user_workload_role_arn: The user_workload_role_arn of this V1EKSCusterDriverStatus.  # noqa: E501
        :type: str
        """

        self._user_workload_role_arn = user_workload_role_arn

    @property
    def vpc_id(self):
        """Gets the vpc_id of this V1EKSCusterDriverStatus.  # noqa: E501


        :return: The vpc_id of this V1EKSCusterDriverStatus.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this V1EKSCusterDriverStatus.


        :param vpc_id: The vpc_id of this V1EKSCusterDriverStatus.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1EKSCusterDriverStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1EKSCusterDriverStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1EKSCusterDriverStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class Externalv1CreateSessionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {'name': 'str', 'spec': 'V1SessionSpec'}

    attribute_map = {'name': 'name', 'spec': 'spec'}

    def __init__(self, name=None, spec=None, _configuration=None):  # noqa: E501
        """Externalv1CreateSessionRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._spec = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if spec is not None:
            self.spec = spec

    @property
    def name(self):
        """Gets the name of this Externalv1CreateSessionRequest.  # noqa: E501


        :return: The name of this Externalv1CreateSessionRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Externalv1CreateSessionRequest.


        :param name: The name of this Externalv1CreateSessionRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def spec(self):
        """Gets the spec of this Externalv1CreateSessionRequest.  # noqa: E501


        :return: The spec of this Externalv1CreateSessionRequest.  # noqa: E501
        :rtype: V1SessionSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this Externalv1CreateSessionRequest.


        :param spec: The spec of this Externalv1CreateSessionRequest.  # noqa: E501
        :type: V1SessionSpec
        """

        self._spec = spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(Externalv1CreateSessionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Externalv1CreateSessionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Externalv1CreateSessionRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1InstanceType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {'cpu': 'str', 'gpu': 'str', 'hourly_cost': 'float', 'memory': 'str', 'name': 'str', 'spot': 'bool'}

    attribute_map = {
        'cpu': 'cpu',
        'gpu': 'gpu',
        'hourly_cost': 'hourlyCost',
        'memory': 'memory',
        'name': 'name',
        'spot': 'spot'
    }

    def __init__(
        self,
        cpu=None,
        gpu=None,
        hourly_cost=None,
        memory=None,
        name=None,
        spot=None,
        _configuration=None
    ):  # noqa: E501
        """V1InstanceType - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu = None
        self._gpu = None
        self._hourly_cost = None
        self._memory = None
        self._name = None
        self._spot = None
        self.discriminator = None

        if cpu is not None:
            self.cpu = cpu
        if gpu is not None:
            self.gpu = gpu
        if hourly_cost is not None:
            self.hourly_cost = hourly_cost
        if memory is not None:
            self.memory = memory
        if name is not None:
            self.name = name
        if spot is not None:
            self.spot = spot

    @property
    def cpu(self):
        """Gets the cpu of this V1InstanceType.  # noqa: E501


        :return: The cpu of this V1InstanceType.  # noqa: E501
        :rtype: str
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """Sets the cpu of this V1InstanceType.


        :param cpu: The cpu of this V1InstanceType.  # noqa: E501
        :type: str
        """

        self._cpu = cpu

    @property
    def gpu(self):
        """Gets the gpu of this V1InstanceType.  # noqa: E501


        :return: The gpu of this V1InstanceType.  # noqa: E501
        :rtype: str
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu):
        """Sets the gpu of this V1InstanceType.


        :param gpu: The gpu of this V1InstanceType.  # noqa: E501
        :type: str
        """

        self._gpu = gpu

    @property
    def hourly_cost(self):
        """Gets the hourly_cost of this V1InstanceType.  # noqa: E501


        :return: The hourly_cost of this V1InstanceType.  # noqa: E501
        :rtype: float
        """
        return self._hourly_cost

    @hourly_cost.setter
    def hourly_cost(self, hourly_cost):
        """Sets the hourly_cost of this V1InstanceType.


        :param hourly_cost: The hourly_cost of this V1InstanceType.  # noqa: E501
        :type: float
        """

        self._hourly_cost = hourly_cost

    @property
    def memory(self):
        """Gets the memory of this V1InstanceType.  # noqa: E501


        :return: The memory of this V1InstanceType.  # noqa: E501
        :rtype: str
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this V1InstanceType.


        :param memory: The memory of this V1InstanceType.  # noqa: E501
        :type: str
        """

        self._memory = memory

    @property
    def name(self):
        """Gets the name of this V1InstanceType.  # noqa: E501


        :return: The name of this V1InstanceType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1InstanceType.


        :param name: The name of this V1InstanceType.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def spot(self):
        """Gets the spot of this V1InstanceType.  # noqa: E501


        :return: The spot of this V1InstanceType.  # noqa: E501
        :rtype: bool
        """
        return self._spot

    @spot.setter
    def spot(self, spot):
        """Sets the spot of this V1InstanceType.


        :param spot: The spot of this V1InstanceType.  # noqa: E501
        :type: bool
        """

        self._spot = spot

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1InstanceType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1InstanceType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1InstanceType):
            return True

        return self.to_dict() != other.to_dict()
